@@ -105,16 +105,18 @@ void TextItem::finalizeConstructor(int sheet) {
   connect(document(), SIGNAL(markupChanged(MarkupData *)),
 	  this, SLOT(markupChange(MarkupData *)));
   connect(document(), &TextItemDoc::noLongerEmpty,
-          [this]() {
-            BlockItem *bi = ancestralBlock();
-            if (bi) {
-              EntryScene *es = dynamic_cast<EntryScene *>(bi->baseScene());
-              if (es)
-                es->redateBlocks();
-            }
-          });
+          this, &TextItem::redate);
 }
 
+void TextItem::redate() {
+  BlockItem *bi = ancestralBlock();
+  if (bi) {
+    EntryScene *es = dynamic_cast<EntryScene *>(bi->baseScene());
+    if (es)
+      es->redateBlocks();
+  }
+}  
+
 bool TextItem::allowNotes() const {
   return mayNote;
 }
@@ -213,11 +215,11 @@ void TextItem::handleLeftClick(QGraphicsSceneMouseEvent *e) {
     if (linkHelper->mousePress(e))
       break;
     int pos = text->find(e->pos());
-    if (pos>=0) {
+    if (pos>=0 && (!clips() || clipRect().contains(posToPoint(pos)))) {
       cursor.setPosition(pos,
                          e->modifiers() & Qt::ShiftModifier
                          ? TextCursor::KeepAnchor
-                         : TextCursor::MoveAnchor);
+                         : TextCursor::MoveAnchor); 
       setFocus();
       update();
     }
@@ -407,8 +409,14 @@ void TextItem::mouseMoveEvent(QGraphicsSceneMouseEvent *evt) {
   switch (mode()->mode()) {
   case Mode::Browse:
   case Mode::Type: {
-    int anc = cursor.hasSelection() ? cursor.anchor() : cursor.position();
-    setTextCursor(TextCursor(text, pos, anc));
+    while (pos>=0) {
+      int anc = cursor.hasSelection() ? cursor.anchor() : cursor.position();
+      setTextCursor(TextCursor(text, pos, anc));
+      QPointF p = posToPoint(pos);
+      if (!clips() || clipRect().contains(p))
+        break;
+      pos -= 1;
+    }
     } break;
   case Mode::Highlight:
   case Mode::Strikeout:
@@ -599,6 +607,7 @@ bool TextItem::keyPressWithControl(QKeyEvent *e) {
   case Qt::Key_A:
     cursor.setPosition(0);
     cursor.movePosition(TextCursor::End, TextCursor::KeepAnchor);
+    ensureCursorVisible();
     update();
     return true;
   case Qt::Key_N:
@@ -922,7 +931,7 @@ int TextItem::substituteInternalScripts(int start, int end) {
     QChar c = document()->characterAt(pos);
     if ((c=="^" || c=="_") && pos<end-1) {
       QString s = QString(c) + QString(document()->characterAt(pos+1));
-      if (Accents::contains(s)) {
+      if (Accents::isScript(s)) {
         TextCursor cur(document(), pos+2, pos);
         cur.deleteChar();
         QString sub = Accents::map(s);
@@ -937,9 +946,13 @@ int TextItem::substituteInternalScripts(int start, int end) {
 }      
 
 bool TextItem::keyPressAsDigraph(QKeyEvent *e) {
+  if (cursor.hasSelection())
+    return false;
+  QString charNow = e->text();
+  if (charNow=="")
+    return false;
   QChar charBefore = document()->characterAt(cursor.position()-1);
   QChar charBefore2 = document()->characterAt(cursor.position()-2);
-  QString charNow = e->text();
   QString digraph = QString(charBefore) + charNow;
   QString trigraph = QString(charBefore2) + digraph;
   if (Digraphs::contains(digraph)) {
@@ -1075,7 +1088,7 @@ static bool balancedBrackets(QString s) {
 }
 
 bool TextItem::unscriptStyles() {
-  // drop old super/subscript 
+  // drop old super/subscript
   cursor.clearSelection();
   
   MarkupData *oldscript = data()->markupAt(cursor.position(),
@@ -1095,12 +1108,30 @@ bool TextItem::unscriptStyles() {
   cursor.movePosition(TextCursor::Right);
   return true;
 }
-  
 
-bool TextItem::tryScriptStyles(bool onlyIfBalanced) {
+bool TextItem::tryAngleBrackets() {
+  cursor.clearSelection();
+  if (document()->characterAt(cursor.position()-1) != '>')
+    return false;
+  TextCursor m = cursor.findBackward("<");
+  if (!m.hasSelection())
+    return false;
+  m.clearSelection();
+  for (int k=m.position(); k<cursor.position(); k++)
+    if (document()->characterAt(k).isSpace())
+      return false;
+  m.deleteChar();
+  m.insertText("⟨");
+  cursor.deletePreviousChar();
+  cursor.insertText("⟩");
+  return true;
+}
+
+bool TextItem::tryScriptStyles(bool onlyifbalanced) {
   /* Returns true if we decide to make a superscript or subscript, that is,
      if there is a preceding "^" or "_".
    */
+  tryAngleBrackets();
   cursor.clearSelection();
   
   if (data()->markupAt(cursor.position(),
@@ -1111,21 +1142,26 @@ bool TextItem::tryScriptStyles(bool onlyIfBalanced) {
 
   bool endswithbrace = document()->characterAt(cursor.position()-1) == '}';
   QString re = "(\\^|_)";
-  if (endswithbrace)
+  if (endswithbrace || onlyifbalanced)
     re += "\\{";
       
   TextCursor m = cursor.findBackward(QRegExp(re));
-  if (!m.hasSelection())
-    return false; // no "^" or "_"
+  if (!m.hasSelection()) {
+    if (endswithbrace)
+      return false;
+    re = "(\\^|_)";
+    m = cursor.findBackward(QRegExp(re));
+    if (!m.hasSelection())
+      return false; // no "^" or "_"
+  }
   if (m.selectionEnd() == cursor.position())
     return false; // empty target
 
   QString mrk = m.selectedText();
 
-  if (onlyIfBalanced) {
+  if (onlyifbalanced) {
     TextCursor scr(document(), m.selectionStart() + 1);
     scr.setPosition(cursor.position(), TextCursor::KeepAnchor);
-    qDebug() << "onlyifbalanced" << scr.selectedText();
     if (!balancedBrackets(scr.selectedText()))
       return false;
   }
@@ -1241,8 +1277,20 @@ void TextItem::toggleSimpleStyle(MarkupData::Style type,
   
   MarkupData *oldmd = data()->markupAt(start, type);
   
-  if (oldmd && oldmd->start()==start && oldmd->end()==end) {
-    deleteMarkup(oldmd);
+  if (oldmd) {
+    // touch or overlap
+    int ostart = oldmd->start();
+    int oend = oldmd->end();
+    if (oend>=end) {
+      // whole section was marked up, we'll drop it
+      deleteMarkup(oldmd);
+      if (ostart<start)
+        addMarkup(type, ostart, start);
+      if (oend>end)
+        addMarkup(type, end, oend);
+    } else {
+      addMarkup(type, start, end);
+    }
   } else if (start<end) {
     addMarkup(type, start, end);
   }
